@@ -79,7 +79,7 @@ namespace QNote {
 	void loadList(QSqlDatabase* db, Guid notebookGuid, QVector<Note>& notelist);
 	void loadForNotebook(QSqlDatabase* db, Guid notebookGuid, QVector<Note>& notelist);
 	void loadCount(QSqlDatabase* db, map<Guid, int>& notebookCounts);
-	void search(QSqlDatabase* db, QStringList words, QString notebookGuid, QVector<Guid> tagGuids, vector<Note>& noteList);
+	void search(QSqlDatabase* db, QStringList words, QString notebookGuid, QVector<Guid> tagGuids, vector<Note>& noteList, int maxNoteCount);
 	void getDirty(QSqlDatabase* db, QVector<Note>& notelist);
 	void getNew(QSqlDatabase* db, QVector<Note>& notelist);
 	void getDeleted(QSqlDatabase* db, QVector<Note>& notelist);
