@@ -220,7 +220,7 @@ namespace QNote {
 		}
 	}
 
-	void search(QSqlDatabase* db, QStringList words, QString notebookGuid, QVector<Guid> tagGuids, vector<Note>& noteList) {
+	void search(QSqlDatabase* db, QStringList words, QString notebookGuid, QVector<Guid> tagGuids, vector<Note>& noteList, int maxNoteCount) {
 		QSqlQuery q(*db);
 		QString searchCriteria = "";
 		Note note;
@@ -254,7 +254,11 @@ namespace QNote {
 		}
 
 		//qDebug() << "select guid from notes " << searchCriteria;
-		q.prepare("select notes.guid from notes " + searchCriteria);
+		if(maxNoteCount <= 0)
+			q.prepare("select notes.guid from notes " + searchCriteria);
+		else
+			q.prepare("select notes.guid from notes " + searchCriteria + " order by notes.created DESC limit " + QString::number(maxNoteCount));
+
 		QItem::executeQuery(q);
 		while(q.next()) {
 			load_shallow(db, q.value(0).toString().toStdString(), note);
