@@ -20,22 +20,23 @@ class QClickableLabel : public QLabel
 	Q_OBJECT
 
 public:
-	QClickableLabel(QWidget* parent = 0): QLabel(parent), isMousePressed(false), isBorderEnabled(true) {
+	QClickableLabel(QWidget* parent = 0): QLabel(parent), isMousePressed(false), isBorderEnabled(true), isClickAnimEnabled(true) {
 		//setFrameStyle(QFrame::NoFrame);
 		setScaledContents(true);
-		setAttribute(Qt::WA_TranslucentBackground);
+		//setAttribute(Qt::WA_TranslucentBackground);
 		anim = new QPropertyAnimation(this, "geometry");
 	}
 
 	~QClickableLabel() { delete anim; }
 
 	void setBorderEnabled(bool borderEnabled) { isBorderEnabled = borderEnabled; }
-
+	void setClickAnimEnabled(bool clickAnimEnabled) { isClickAnimEnabled = clickAnimEnabled; }
 	void mousePressEvent(QMouseEvent* e)
 	{
 		//this->setFrameStyle(QFrame::Box);
 		//this->setGraphicsEffect(new QGraphicsBlurEffect(this));
-		setGeometry(QRect(QPoint(geometry().x(), geometry().y()), size() - QSize(2,2)));
+		if(isClickAnimEnabled)
+			setGeometry(QRect(QPoint(geometry().x(), geometry().y()), size() - QSize(2,2)));
 		mousePos = e->pos();
 		isMousePressed = true;
 		e->accept();
@@ -47,7 +48,8 @@ public:
 	{
 		//this->setFrameStyle(QFrame::NoFrame);
 		//setFixedSize(size() + QSize(2,2));
-		setGeometry(QRect(QPoint(geometry().x(), geometry().y()), size() + QSize(2,2)));
+		if(isClickAnimEnabled)
+			setGeometry(QRect(QPoint(geometry().x(), geometry().y()), size() + QSize(2,2)));
 		//this->setGraphicsEffect(NULL);
 		emit mouseReleased();
 
@@ -96,7 +98,7 @@ public:
 
 	void animHide() {
 		//qDebug() << __FUNCTION__ << width() << height() << geometry() << size();
-		QObject::connect(anim, SIGNAL(finished()), this, SLOT(hide()));
+		QObject::connect(anim, SIGNAL(finished()), this, SLOT(hide()), Qt::QueuedConnection);
 		anim->setStartValue(QRect(QPoint(geometry().x(), geometry().y()), size()));
 		anim->setEndValue(QRect(geometry().x() + size().width() / 2, geometry().y() + size().height() / 2, 0, 0));
 		anim->setDuration(150);
@@ -122,6 +124,7 @@ private:
 	QPoint	mousePos;
 	bool isMousePressed;
 	bool isBorderEnabled;
+	bool isClickAnimEnabled;
 	QPropertyAnimation* anim;
 
 };
