@@ -24,8 +24,8 @@ public:
 public slots:
 	void setItemMark(QListWidgetItem *item);
    	void deleteSelectedNotebooks();
-    void addSelectedCount() { m_lSelectedCount.setText(QString("%1 notebooks").arg(++m_iSelectedCount)); }
-    void subSelectedCount() { m_lSelectedCount.setText(QString("%1 notebooks").arg(--m_iSelectedCount)); }
+    void addSelectedCount() { m_lSelectedCount.setText(QString(trUtf8("%1 notebooks")).arg(++m_iSelectedCount)); }
+    void subSelectedCount() { m_lSelectedCount.setText(QString(trUtf8("%1 notebooks")).arg(--m_iSelectedCount)); }
 
 private:
     Ui::QDeleteNotebookViewClass ui;
