@@ -10,6 +10,8 @@
 #include <QWebElement>
 #ifdef Q_WS_MAEMO_5
 #include "QMaemoTextSelectionSupressor.h"
+#include <QGeoPositionInfoSource>
+QTM_USE_NAMESPACE
 #endif
 
 
@@ -40,9 +42,12 @@ public slots:
     void setTag(bool, Tag);
     void loadResource(QUrl);
     void insertTodo();
-
-    void zoominView();
-    void zoomoutView();
+    void startGpsLocationUpdate();
+#ifdef Q_WS_MAEMO_5
+    void positionUpdated(const QGeoPositionInfo&);
+#endif
+    //void zoominView();
+    //void zoomoutView();
 
     void setDirtyData() { hasDirtyData = true; }
 
@@ -70,6 +75,7 @@ private:
     bool	hasDirtyData;
 #ifdef Q_WS_MAEMO_5
 	QMaemoTextSelectionSupressor* supressor;
+	QGeoPositionInfoSource *source;
 #endif
 };
 
