@@ -4,7 +4,7 @@
 #include "QNotesView.h"
 #include "QNoteEditWindow.h"
 #include "QClickableLabel.h"
-//#include "QWebViewEventFilter.h"
+//#include trUtf8("QWebViewEventFilter.h")
 #include <QDesktopServices>
 
 #ifdef Q_WS_MAEMO_5
@@ -13,10 +13,12 @@
 #endif
 
 //#ifdef Q_WS_MAEMO_5
-//#include "QMaemoMapViewDialog.h"
+//#include trUtf8("QMaemoMapViewDialog.h")
 //#else
 #include "QGoogleMapViewDialog.h"
 //#endif
+#include "QPdfPreviewDialog.h"
+#include "QAudioPreviewDialog.h"
 
 QNoteViewWindow::QNoteViewWindow(const Note& note, QWidget *parent)
     : QvernoteWindow(parent), m_Note(note), isNavControlsVisible(false)
@@ -34,7 +36,8 @@ QNoteViewWindow::QNoteViewWindow(const Note& note, QWidget *parent)
 	ui.wvNoteView->settings()->setAttribute(QWebSettings::LocalContentCanAccessRemoteUrls, false);
 
 	webViewSlide = new QPropertyAnimation(ui.wvNoteView, "geometry");
-	webViewSlide->setDuration(100);
+	webViewSlide->setDuration(150);
+	webViewSlide->setEasingCurve(QEasingCurve::InQuad);
 
 	ui.lFavorite->setBorderEnabled(false);
 	ui.lFavorite->setClickAnimEnabled(false);
@@ -52,8 +55,8 @@ QNoteViewWindow::QNoteViewWindow(const Note& note, QWidget *parent)
 	QMenuBar* noteViewMenu = new QMenuBar();
 	QAction* actEditNote = new QAction(QIcon(":/IconAdd/general_sketch.png"), "Edit", this);
 	QAction* actEmailNote = new QAction(QIcon(":/IconAdd/general_email.png"), "Email", this);
-	//QAction* actZoomin = new QAction(QIcon(":/IconAdd/note_zoomin.png"), "Zoom In", this);
-	//QAction* actZoomout = new QAction(QIcon(":/IconAdd/note_zoomout.png"), "Zoom Out", this);
+	//QAction* actZoomin = new QAction(QIcon(":/IconAdd/note_zoomin.png"), "Zoom In"), this);
+	//QAction* actZoomout = new QAction(QIcon(":/IconAdd/note_zoomout.png"), "Zoom Out"), this);
 
 	QAction* actNext = new QAction(QIcon(":/IconAdd/general_forward.png"), "Next", this);
 	QAction* actPrev = new QAction(QIcon(":/IconAdd/general_back.png"), "Previous", this);
@@ -89,7 +92,7 @@ QNoteViewWindow::QNoteViewWindow(const Note& note, QWidget *parent)
 
 	QObject::connect(ui.lFavorite, SIGNAL(clicked()), SLOT(onFavoriteClicked()));
 
-	QObject::connect(ui.wvNoteView, SIGNAL(linkClicked(QUrl)), this, SLOT(loadResource(QUrl)));
+	QObject::connect(ui.wvNoteView, SIGNAL(linkClicked(QUrl)), this, SLOT(openLink(QUrl)));
 	backgroundLoad();
 }
 
@@ -104,17 +107,17 @@ QNoteViewWindow::~QNoteViewWindow()
 
 void QNoteViewWindow::showEvent ( QShowEvent * )
 {
-	//qDebug() << __FUNCTION__ << "Loading note";
+	//qDebug() << __FUNCTION__ << trUtf8("Loading note");
 	savedWebViewGeometry = ui.wvNoteView->geometry();
 	//backgroundLoad();
 }
 
 bool QNoteViewWindow::loadNote()
 {
-	//qDebug() << "Loading note";
+	//qDebug() << trUtf8("Loading note");
 	if(m_hEvernote->getNoteContent(m_Note) == false)
 	{
-		displayError("Unable to load note", QString(m_hEvernote->getLastErrorString().c_str()));
+		displayError(trUtf8("Unable to load note"), QString(m_hEvernote->getLastErrorString().c_str()));
 		setProgressIndicator(false);
 		return false;
 	}
@@ -124,10 +127,9 @@ bool QNoteViewWindow::loadNote()
 
 void QNoteViewWindow::displayNote()
 {
-	//ui.wvNoteView->setVisible(false);
 	enmlReader->parse(m_Note);
 	ui.wvNoteView->setHtml(enmlReader->getHtml());
-
+	ui.wvNoteView->page()->mainFrame()->addToJavaScriptWindowObject("JSApi",this);
 	ui.scrollArea->ensureVisible(0, 0);
 }
 
@@ -163,59 +165,69 @@ void QNoteViewWindow::resizeWebView()
 	const QRect fr = ui.wvNoteView->frameGeometry();
 	const QRect cr = ui.wvNoteView->contentsRect();
 
-	//qDebug() << "contentSize" << s;
-	//qDebug() << "frameGeometry" << fr;
-	//qDebug() << "contentRect" << cr;
+	//qDebug() << trUtf8("contentSize") << s;
+	//qDebug() << trUtf8("frameGeometry") << fr;
+	//qDebug() << trUtf8("contentRect") << cr;
 	//s.setHeight(s.height() + 1 * ui.wvNoteEdit->fontMetrics().lineSpacing());
 	ui.wvNoteView->setMinimumHeight(qMax(70, s.height()  + (fr.height() - cr.height() - 1) + 20));
 	ui.wvNoteView->setMinimumWidth(qMax(geometry().width() - 16, s.width()));
 	ui.wvNoteView->setZoomFactor(1.0);
+	updateHeader();
 	setProgressIndicator(false);
 }
 
-void QNoteViewWindow::loadResource(QUrl url)
+void QNoteViewWindow::updateHeader()
 {
-	setProgressIndicator(true);
-	//qDebug() << __FUNCTION__ << QByteArray::fromHex(url.toString().toAscii());
-	Resource r;
+	Notebook notebook;
 
-	if(url.toString().startsWith("http://"))
+	if(QvernoteStorage::Instance()->isNoteFavorite(m_Note.guid))
 	{
-		QDesktopServices::openUrl(url);
+		ui.lFavorite->setPixmap(QPixmap(":/IconAdd/Star-full-48.png"));
+		ui.lFavorite->setProperty("isFavorite", QVariant(true));
 	}
 	else
 	{
-		if(m_hEvernote->loadResourceByHash(r, m_Note.guid, QByteArray::fromHex(url.toString().toAscii()).data()) == true)
-		{
-			QString fileName = QFileDialog::getSaveFileName(
-					this,
-					tr("Save resource"),
-					"/MyDocs/" + QString::fromStdString(r.attributes.fileName),
-					tr("Images (*.png *.gif *.jpg);;Audio (*.wav *.mpg *.amr *.mp3);;Documents (*.pdf);;Other (*)"));
-
-			if(fileName.size() > 0)
-			{
-				QFile file(fileName);
-				if (!file.open(QIODevice::WriteOnly))
-				{
-					displayError("Cannot write file", file.errorString());
-					return;
-				}
-
-				QDataStream out(&file);
-				out.writeRawData(r.data.body.c_str(), r.data.size);
-				file.close();
-				qDebug() << "Resource saved";
-			}
-		}
-		else
-		{
-			displayError("Failed to load resource", QString::fromStdString(m_hEvernote->getLastErrorString()));
-		}
+		ui.lFavorite->setPixmap(QPixmap(":/IconAdd/Star-empty-48.png"));
+		ui.lFavorite->setProperty("isFavorite", QVariant(false));
 	}
+
+	ui.lNoteTitle->setText(QString::fromUtf8(m_Note.title.c_str()));
+
+	if(m_hEvernote->getNotebookByGuid(notebook, m_Note.notebookGuid))
+		ui.lNotebookName->setText(QString(trUtf8("In: ")) + QString::fromUtf8(notebook.name.c_str()));
+	else
+		ui.lNotebookName->setText(trUtf8("Unknown notebook"));
+
+	/* load tag names */
+	vector<string>::iterator it;
+	QString tagList = 0;
+	for(it = m_Note.tagNames.begin(); it < m_Note.tagNames.end(); it++)
+	{
+		tagList += QString::fromUtf8((*it).c_str()) + " ";
+	}
+
+	if(tagList.size() == 0)
+		ui.lNoteTags->setText(trUtf8("No tags"));
+	else
+		ui.lNoteTags->setText(tagList);
+}
+
+void QNoteViewWindow::openLink(QUrl url)
+{
+	setProgressIndicator(true);
+	//qDebug() << __FUNCTION__ << QByteArray::fromHex(url.toString().toAscii());
+
+
+	if(url.toString().startsWith(trUtf8("http://")))
+	{
+		QDesktopServices::openUrl(url);
+	}
+
 	setProgressIndicator(false);
 }
 
+
+
 void QNoteViewWindow::zoominView()
 {
 	navigationControlTimer->start(3000);
@@ -287,42 +299,9 @@ void QNoteViewWindow::loadPrevNote()
 
 void QNoteViewWindow::backgroundLoad()
 {
-	Notebook notebook;
-
 	setProgressIndicator(true);
-	//ui.wvNoteView->setHtml("<center><font size=\"18\" color=\"#37b4fc\">Loading...</font></center>");
-	//ui.wvNoteView->setHtml("");
-	if(QvernoteStorage::Instance()->isNoteFavorite(m_Note.guid))
-	{
-		ui.lFavorite->setPixmap(QPixmap(":/IconAdd/Star-full-48.png"));
-		ui.lFavorite->setProperty("isFavorite", QVariant(true));
-	}
-	else
-	{
-		ui.lFavorite->setPixmap(QPixmap(":/IconAdd/Star-empty-48.png"));
-		ui.lFavorite->setProperty("isFavorite", QVariant(false));
-	}
-
-	ui.lNoteTitle->setText(QString::fromUtf8(m_Note.title.c_str()));
-
-	if(m_hEvernote->getNotebookByGuid(notebook, m_Note.notebookGuid))
-		ui.lNotebookName->setText(QString("In: ") + QString::fromUtf8(notebook.name.c_str()));
-	else
-		ui.lNotebookName->setText("Unknown notebook");
-
-	/* load tag names */
-	vector<string>::iterator it;
-	QString tagList = 0;
-	for(it = m_Note.tagNames.begin(); it < m_Note.tagNames.end(); it++)
-	{
-		tagList += QString::fromUtf8((*it).c_str()) + " ";
-	}
-
-	if(tagList.size() == 0)
-		ui.lNoteTags->setText("No tags");
-	else
-		ui.lNoteTags->setText(tagList);
 
+	QObject::disconnect(webViewSlide, SIGNAL(finished()), this, SLOT(resizeWebView()));
 	QObject::connect(webViewSlide, SIGNAL(finished()), this, SLOT(startBackgroundTask()));
 	webViewSlide->setStartValue(ui.wvNoteView->geometry());
 	if(slideLeft)
@@ -331,8 +310,6 @@ void QNoteViewWindow::backgroundLoad()
 		webViewSlide->setEndValue(QRect(ui.wvNoteView->geometry().topRight(), ui.wvNoteView->size()));
 
 	webViewSlide->start();
-
-	//m_pBackgroundJob->start();
 }
 
 void QNoteViewWindow::initNavigationControls()
@@ -401,35 +378,6 @@ void QNoteViewWindow::initNavigationControls()
 	QObject::connect(navigationControlTimer, SIGNAL(timeout()), SLOT(hideNavigationControls()));
 }
 
-/*
-void QNoteViewWindow::mousePressEvent(QMouseEvent* e)
-{
-	mousePos = e->pos();
-	isMousePressed = true;
-	e->accept();
-	QWidget::mousePressEvent(e);
-}
-
-void QNoteViewWindow::mouseReleaseEvent(QMouseEvent* e)
-{
-	if(isMousePressed)
-	{
-		isMousePressed = false;
-		displayNavigationControls();
-	}
-
-	QWidget::mouseReleaseEvent(e);
-}
-
-void QNoteViewWindow::mouseMoveEvent(QMouseEvent* e)
-{
-	QRect r(mousePos, e->pos());
-	if(abs(r.height()) > 20 || abs(r.width()) > 20)
-		isMousePressed = false;
-
-	QWidget::mouseMoveEvent(e);
-}*/
-
 void QNoteViewWindow::displayNavigationControls()
 {
 	if(isNavControlsVisible == false)
@@ -499,3 +447,86 @@ void QNoteViewWindow::onFavoriteClicked()
 		ui.lFavorite->setProperty("isFavorite", QVariant(true));
 	}
 }
+
+void QNoteViewWindow::handleResource(QString resourceHash)
+{
+	QResourceHandlerDialog dlg(m_Note, resourceHash, this);
+	dlg.exec();
+}
+
+QResourceHandlerDialog::QResourceHandlerDialog(Note& note, QString resourceHash, QWidget* parent)
+: QDialog(parent), m_Note(note), m_resourceHash(resourceHash)
+{
+	setWindowTitle(trUtf8("Choose action"));
+	layout = new QGridLayout(this);
+	bSave.setText(trUtf8("Save"));
+	bPreview.setText(trUtf8("Preview"));
+	QObject::connect(&bSave, SIGNAL(clicked()), SLOT(storeResource()));
+	QObject::connect(&bPreview, SIGNAL(clicked()), SLOT(previewResource()));
+	layout->addWidget(&bSave, 1, 1);
+	layout->addWidget(&bPreview, 1, 2);
+}
+
+void QResourceHandlerDialog::storeResource()
+{
+	Resource r;
+
+	if(QvernoteAPI::Instance()->loadResourceByHash(r, m_Note.guid, QByteArray::fromHex(m_resourceHash.toAscii()).data()) == true)
+	{
+		QString fileName = QFileDialog::getSaveFileName(
+				this,
+				tr("Save resource"),
+				"/MyDocs/" + QString::fromStdString(r.attributes.fileName),
+				tr("Images (*.png *.gif *.jpg);;Audio (*.wav *.mpg *.amr *.mp3);;Documents (*.pdf);;Other (*)"));
+
+		if(fileName.size() > 0)
+		{
+			QFile file(fileName);
+			if (!file.open(QIODevice::WriteOnly))
+			{
+				QvernoteWindow::displayError(this, trUtf8("Cannot write file"), file.errorString());
+				return;
+			}
+
+			QDataStream out(&file);
+			out.writeRawData(r.data.body.c_str(), r.data.size);
+			file.close();
+			qDebug() << "Resource saved";
+		}
+	}
+	else
+	{
+		QvernoteWindow::displayError(this, trUtf8("Failed to load resource"), QString::fromStdString(QvernoteAPI::Instance()->getLastErrorString()));
+	}
+
+	close();
+}
+
+void QResourceHandlerDialog::previewResource()
+{
+	Resource r;
+
+#ifdef Q_WS_MAEMO_5
+	setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
+#endif
+
+	if(QvernoteAPI::Instance()->loadResourceByHash(r, m_Note.guid, QByteArray::fromHex(m_resourceHash.toAscii()).data()) == true)
+	{
+		if(r.mime == "application/pdf")
+		{
+			QPdfPreviewDialog dlg(r, this);
+			dlg.exec();
+		}
+		else if(r.mime == "audio/mpeg" || r.mime == "audio/wav")
+		{
+			QAudioPreviewDialog dlg(r, this);
+			dlg.exec();
+		}
+		else
+		{
+			QvernoteWindow::displayError(parentWidget(), trUtf8("Preview is unavailable for media type"), QString::fromStdString(r.mime));
+		}
+	}
+
+	close();
+}
