@@ -226,8 +226,8 @@ void QNotesView::onNoteLoadDone()
 
 void QNotesView::orientationChanged()
 {
-	while(isSynchronizing)
-	loadNotesIntoView();
+	if(!isSynchronizing)
+		loadNotesIntoView();
 }
 
 void QNotesView::setNoteDisplayOrderAsc()
