@@ -8,7 +8,7 @@
 #include "QvernoteView.h"
 #include <QDebug>
 #include <QMessageBox>
-
+#include "QNotebookPickList.h"
 
 static void populateListModel(QStandardItemModel *model, QList<QString>& listValues);
 
@@ -96,6 +96,50 @@ QOptionsDialog::QOptionsDialog(QWidget *parent)
 
 	ui.gridLayout_2->addWidget(vbNotesViewSelection, 7, 0, 1, 2);
 
+	QStandardItemModel* maxNoteCountModel = new QStandardItemModel(0, 1);
+	QMaemo5ValueButton* vbMaxNoteCountSelection = new QMaemo5ValueButton(trUtf8("Note limit"));
+	vbMaxNoteCountSelection->setValueLayout(QMaemo5ValueButton::ValueBesideText);
+	maxNoteCountSelector = new QMaemo5ListPickSelector;
+
+	listValues.clear();
+	listValues.append(trUtf8("No limit"));
+	listValues.append("50");
+	listValues.append("100");
+	listValues.append("150");
+	listValues.append("200");
+	listValues.append("250");
+	listValues.append("300");
+
+	populateListModel(maxNoteCountModel, listValues);
+
+	maxNoteCountSelector->setModel(maxNoteCountModel);
+	switch(settings->getMaxNoteCount()) {
+	case 0:
+		maxNoteCountSelector->setCurrentIndex(0);
+		break;
+	case 50:
+		maxNoteCountSelector->setCurrentIndex(1);
+		break;
+	case 100:
+		maxNoteCountSelector->setCurrentIndex(2);
+		break;
+	case 150:
+		maxNoteCountSelector->setCurrentIndex(3);
+		break;
+	case 200:
+		maxNoteCountSelector->setCurrentIndex(4);
+		break;
+	case 250:
+		maxNoteCountSelector->setCurrentIndex(5);
+		break;
+	case 300:
+		maxNoteCountSelector->setCurrentIndex(6);
+		break;
+	}
+	vbMaxNoteCountSelection->setPickSelector(maxNoteCountSelector);
+
+	ui.gridLayout_2->addWidget(vbMaxNoteCountSelection, 8, 0, 1, 2);
+
 	QStandardItemModel* mapsProviderSelectionModel = new QStandardItemModel(0, 1);
 	QMaemo5ValueButton* vbMapsProviderSelection = new QMaemo5ValueButton(trUtf8("Maps provider"));
 	vbMapsProviderSelection->setValueLayout(QMaemo5ValueButton::ValueBesideText);
@@ -111,14 +155,19 @@ QOptionsDialog::QOptionsDialog(QWidget *parent)
 	mapsProviderSelector->setCurrentIndex(settings->getMapsProvider());
 	vbMapsProviderSelection->setPickSelector(mapsProviderSelector);
 
-	ui.gridLayout_2->addWidget(vbMapsProviderSelection, 8, 0, 1, 2);
+	ui.gridLayout_2->addWidget(vbMapsProviderSelection, 9, 0, 1, 2);
+
+	pbBlacklistedNotebooks.setText(trUtf8("Blacklisted notebooks"));
+	m_slBlacklistedNotebooks = settings->getBlacklistedNotebooks().split(',');
+	QObject::connect(&pbBlacklistedNotebooks, SIGNAL(clicked()), this, SLOT(selectBlacklistedNotebooks()));
+	ui.gridLayout_2->addWidget(&pbBlacklistedNotebooks, 10, 0, 1, 2);
 
 	pbDeleteThumbs.setText(trUtf8("Clear thumbnails"));
 	QObject::connect(&pbDeleteThumbs, SIGNAL(clicked()), this, SLOT(deleteThumbnails()));
-	ui.gridLayout_2->addWidget(&pbDeleteThumbs, 9, 0, 1, 2);
+	ui.gridLayout_2->addWidget(&pbDeleteThumbs, 11, 0, 1, 2);
 	pbDropDB.setText(trUtf8("Delete offline database"));
 	QObject::connect(&pbDropDB, SIGNAL(clicked()), this, SLOT(onDropDBClick()));
-	ui.gridLayout_2->addWidget(&pbDropDB, 10, 0, 1, 2);
+	ui.gridLayout_2->addWidget(&pbDropDB, 12, 0, 1, 2);
 
 	QObject::connect(ui.pbSave, SIGNAL(clicked()), SLOT(onSaveSettingsClick()));
 	QObject::connect(this, SIGNAL(triggerDisplayError(QString, QString)), SLOT(onDisplayError(QString, QString)));
@@ -212,7 +261,14 @@ void QOptionsDialog::saveSettings()
 	}
 
 	settings->setNotesView((QvernoteSettings::NotesView)notesViewSelector->currentIndex());
+	settings->setMaxNoteCount(maxNoteCountSelector->currentValueText().toInt());
 	settings->setMapsProvider((QvernoteSettings::MapsProvider)mapsProviderSelector->currentIndex());
+
+	if(settings->getBlacklistedNotebooks() != m_slBlacklistedNotebooks.join(","))
+	{
+		settings->setBlacklistedNotebooks(m_slBlacklistedNotebooks.join(","));
+		emit triggerReloadNotebookList();
+	}
 	//close();
 }
 
@@ -239,12 +295,12 @@ void QOptionsDialog::configureOnlineMode(bool checked)
 	if(h->setOnline(checked) == false)
 	{
 		//dynamic_cast<QvernoteView*>(parentWidget())->displayError(QString(trUtf8("Failed to go %1").arg((checked)? "online" : "offline")), QString::fromStdString(h->getLastErrorString()));
-		emit triggerDisplayError(QString(trUtf8("Failed to go %1").arg((checked)? "online" : "offline")), QString::fromStdString(h->getLastErrorString()));
+		emit triggerDisplayError(QString(trUtf8("Failed to go %1").arg((checked)? trUtf8("online") : trUtf8("offline"))), QString::fromStdString(h->getLastErrorString()));
 	}
 	else
 	{
 		//dynamic_cast<QvernoteView*>(parentWidget())->displayInformationBox(QString(trUtf8("Working %1").arg((checked)? "online" : "offline")));
-		emit triggerDisplayInfo(QString(trUtf8("Working %1").arg((checked)? "online" : "offline")));
+		emit triggerDisplayInfo(QString(trUtf8("Working %1").arg((checked)? trUtf8("online") : trUtf8("offline"))));
 
 		if(h->isOnline())
 			//dynamic_cast<QvernoteView*>(parentWidget())->initView();
@@ -279,6 +335,24 @@ void QOptionsDialog::configureOrientation(QvernoteSettings::DisplayOrientation o
 	dynamic_cast<QvernoteView*>(parentWidget())->setDisplayOrientation(o);
 }
 
+void QOptionsDialog::selectBlacklistedNotebooks()
+{
+	QNotebookPickList dlg("", this);
+	dlg.setMultipleSelection(true);
+	QObject::connect(&dlg, SIGNAL(notebookSelected(bool, QString, QString)), this, SLOT(onBlacklistedNotebookSelected(bool, QString, QString)));
+	m_slBlacklistedNotebooks = QvernoteSettings::Instance()->getBlacklistedNotebooks().split(',');
+	dlg.loadNotebooks(m_slBlacklistedNotebooks);
+	dlg.exec();
+}
+
+void QOptionsDialog::onBlacklistedNotebookSelected(bool checked, QString notebookName, QString notebookGuid)
+{
+	if(checked)
+		m_slBlacklistedNotebooks.append(notebookGuid);
+	else
+		m_slBlacklistedNotebooks.removeAll(notebookGuid);
+}
+
 void QOptionsDialog::deleteThumbnails()
 {
 	if(QMessageBox::question(this, trUtf8("Delete thumbnails"), trUtf8("Are you sure?"),
