@@ -16,11 +16,11 @@ QTagSelectorDialog::QTagSelectorDialog(const Note& note, QWidget *parent)
 
 	if(note.title.empty())
 	{
-		this->setWindowTitle("Tags for Untitled");
+		this->setWindowTitle(trUtf8("Tags for Untitled"));
 	}
 	else
 	{
-		this->setWindowTitle("Tags for " + QString::fromStdString(note.title));
+		this->setWindowTitle(trUtf8("Tags for ") + QString::fromStdString(note.title));
 	}
 
 	QObject::connect(ui.pbNewTag, SIGNAL(clicked()), this, SLOT(addNewTag()));
@@ -30,9 +30,9 @@ QTagSelectorDialog::QTagSelectorDialog(const Note& note, QWidget *parent)
 	if(m_hEvernote->loadTagList() == false)
 	{
 #ifdef Q_WS_MAEMO_5
-		QMaemo5InformationBox::information(this, "Error loading tag list: " + QString(m_hEvernote->getLastErrorString().c_str()), QMaemo5InformationBox::DefaultTimeout);
+		QMaemo5InformationBox::information(this, trUtf8("Error loading tag list: ") + QString(m_hEvernote->getLastErrorString().c_str()), QMaemo5InformationBox::DefaultTimeout);
 #else
-		QMessageBox::critical(this, "Error loading tag list", QString(m_hEvernote->getLastErrorString().c_str()));
+		QMessageBox::critical(this, trUtf8("Error loading tag list"), QString(m_hEvernote->getLastErrorString().c_str()));
 #endif
 	}
 
@@ -97,9 +97,9 @@ void QTagSelectorDialog::addNewTag()
 	else
 	{
 #ifdef Q_WS_MAEMO_5
-		QMaemo5InformationBox::information(this, "Failed to add new tag: " + QString(m_hEvernote->getLastErrorString().c_str()), QMaemo5InformationBox::DefaultTimeout);
+		QMaemo5InformationBox::information(this, trUtf8("Failed to add new tag: ") + QString(m_hEvernote->getLastErrorString().c_str()), QMaemo5InformationBox::DefaultTimeout);
 #else
-		QMessageBox::critical(this, "Failed to add new tag", QString(m_hEvernote->getLastErrorString().c_str()));
+		QMessageBox::critical(this, trUtf8("Failed to add new tag"), QString(m_hEvernote->getLastErrorString().c_str()));
 #endif
 	}
 #ifdef Q_WS_MAEMO_5
