@@ -25,8 +25,8 @@ public slots:
 	void setItemMark(QListWidgetItem *item);
 	void deleteSelectedNotes();
 	void restoreSelectedNotes();
-	void addSelectedCount() { m_lSelectedCount.setText(QString("%1 notes").arg(++m_iSelectedCount)); }
-	void subSelectedCount() { m_lSelectedCount.setText(QString("%1 notes").arg(--m_iSelectedCount)); }
+	void addSelectedCount() { m_lSelectedCount.setText(QString(trUtf8("%1 notes")).arg(++m_iSelectedCount)); }
+	void subSelectedCount() { m_lSelectedCount.setText(QString(trUtf8("%1 notes")).arg(--m_iSelectedCount)); }
 
 private:
 	Ui::QTrashWindowClass ui;
